
Verify integrity using checksums
-------

**Description:**

Always use checksums when working with interpreted code, libraries, executables, 
and configuration files, when these checksums do not match you can determine that 
these files are corrupted or backdoor-ed.


**Solution:**

Verify that the integrity of interpreted code, libraries, executables, and configuration
files is verified using checksums or hashes (not MD5).
